===============
Getting started
===============


.. _section_install:

Installation
============
cellsino is written in pure Python and supports Python version 3.6
and later. To install, run

.. code::

    pip install cellsino

